@@ -15,9 +15,7 @@ from fief.schemas.workspace import WorkspaceCreate
 from fief.services.main_workspace import get_main_fief_client, get_main_fief_workspace
 from fief.services.workspace_db import WorkspaceDatabase
 
-LOCALHOST_DOMAIN_PATTERN = re.compile(
-    r"([^\.]+\.)?localhost(\d+)?", flags=re.IGNORECASE
-)
+LOCALHOST_HOST_PATTERN = re.compile(r"([^\.]+\.)?localhost(\d+)?", flags=re.IGNORECASE)
 
 
 class WorkspaceCreation:
@@ -104,7 +102,7 @@ class WorkspaceCreation:
             client_manager = ClientManager(session)
             fief_client = await get_main_fief_client()
 
-            localhost_domain = LOCALHOST_DOMAIN_PATTERN.match(workspace.domain)
+            localhost_domain = LOCALHOST_HOST_PATTERN.match(workspace.domain)
             redirect_uri = f"{'http' if localhost_domain else 'https'}://{workspace.domain}/admin/api/auth/callback"
             fief_client.redirect_uris = fief_client.redirect_uris + [redirect_uri]
 
